@@ -498,7 +498,7 @@ public:
     std::list<int> userEnabledPeers;
 
     /// True if this device is active
-    bool isActive_;
+    std::atomic<bool>  isActive_;
 
 
     MemoryPool* default_mem_pool_;  //!< Default memory pool for this device
