@@ -89,6 +89,14 @@ class ProfilingSignal : public amd::ReferenceCountedObject {
 
   Flags flags_;
 
+  //! Cached timing data - populated when signal completes, avoids repeated HSA calls
+  struct CachedTiming {
+    uint64_t start_ = 0;   //!< Cached start timestamp from HSA
+    uint64_t end_ = 0;     //!< Cached end timestamp from HSA
+    bool valid_ = false;   //!< True if timing data has been cached
+  };
+  CachedTiming cached_timing_;
+
   ProfilingSignal()
       : ts_(nullptr),
         engine_(HwQueueEngine::Compute),
@@ -101,6 +109,27 @@ class ProfilingSignal : public amd::ReferenceCountedObject {
 
   virtual ~ProfilingSignal();
   amd::Monitor& LockSignalOps() { return lock_; }
+
+  //! Cache timing data from HSA for this signal (called once when signal completes)
+  void CacheTimingData(hsa_agent_t gpu_device);
+
+  //! Reset cached timing for signal reuse
+  void ResetCachedTiming() {
+    amd::ScopedLock lock(lock_);
+    cached_timing_.start_ = 0;
+    cached_timing_.end_ = 0;
+    cached_timing_.valid_ = false;
+  }
+
+  //! Check if timing is already cached
+  bool IsTimingCached() const { return cached_timing_.valid_; }
+
+  //! Get cached timing values
+  void GetCachedTiming(uint64_t& start, uint64_t& end) {
+    amd::ScopedLock lock(lock_);
+    start = cached_timing_.start_;
+    end = cached_timing_.end_;
+  }
 };
 
 class Sampler : public device::Sampler {
@@ -133,7 +162,7 @@ class Sampler : public device::Sampler {
 class NullDevice : public amd::Device {
  public:
   //! constructor
-  NullDevice() {};
+  NullDevice(){};
 
   //! create the device
   bool create(const amd::Isa& isa);
@@ -148,7 +177,7 @@ class NullDevice : public amd::Device {
 
   const Settings& settings() const { return static_cast<Settings&>(*settings_); }
 
-  //! Construct an HSAIL program object from the ELF assuming it is valid
+  //! Construct an device program object from the ELF assuming it is valid
   device::Program* createProgram(amd::Program& owner,
                                  amd::option::Options* options = nullptr) override;
 
@@ -279,6 +308,20 @@ class NullDevice : public amd::Device {
     return false;
   }
 
+  //! Empty implementation on Null device
+  bool amdFileRead(amd::Os::FileDesc handle, void* devicePtr, uint64_t size, int64_t file_offset,
+                uint64_t* size_copied, int32_t* status) override {
+    ShouldNotReachHere();
+    return false;
+  }
+
+  //! Empty implementation on Null device
+  bool amdFileWrite(amd::Os::FileDesc handle, void* devicePtr, uint64_t size, int64_t file_offset,
+                 uint64_t* size_copied, int32_t* status) override {
+    ShouldNotReachHere();
+    return false;
+  }
+
   bool SetClockMode(const cl_set_device_clock_mode_input_amd setClockModeInput,
                     cl_set_device_clock_mode_output_amd* pSetClockModeOutput) override {
     return true;
@@ -359,7 +402,7 @@ class Device : public NullDevice {
   //! Instantiate a new virtual device
   virtual device::VirtualDevice* createVirtualDevice(amd::CommandQueue* queue = nullptr);
 
-  //! Construct an HSAIL program object from the ELF assuming it is valid
+  //! Construct an device program object from the ELF assuming it is valid
   virtual device::Program* createProgram(amd::Program& owner,
                                          amd::option::Options* options = nullptr);
 
@@ -407,6 +450,11 @@ class Device : public NullDevice {
                           const void* agentInfo = nullptr) const override;  // nullptr uses default CPU agent
   virtual void hostFree(void* ptr, size_t size = 0) const;
 
+  virtual bool amdFileRead(amd::Os::FileDesc handle, void* devicePtr, uint64_t size, int64_t file_offset,
+                        uint64_t* size_copied, int32_t* status) override;
+  virtual bool amdFileWrite(amd::Os::FileDesc handle, void* devicePtr, uint64_t size, int64_t file_offset,
+                         uint64_t* size_copied, int32_t* status) override;
+
   bool deviceAllowAccess(void* dst) const;
 
   bool allowPeerAccess(device::Memory* memory) const;
@@ -543,7 +591,7 @@ class Device : public NullDevice {
 
   virtual amd::Memory* GetArenaMemObj(const void* ptr, size_t& offset, size_t size = 0);
 
-  const uint32_t getPreferredNumaNode() const { return preferred_numa_node_; }
+  virtual uint32_t getPreferredNumaNode() const final { return preferred_numa_node_; }
 
   const bool isFineGrainSupported() const;
 
@@ -680,4 +728,3 @@ void callbackQueue(hsa_status_t status, hsa_queue_t* queue, void* data);
 /**
  * @}
  */
-
